@@ -27,6 +27,10 @@
  * See the ChangeLog files for a list of changes. 
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <string.h>
 
 #include <glade/glade-xml.h>
@@ -221,11 +225,11 @@ dialog_replace_get_dialog (void)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->dialog),
 					 GEDIT_RESPONSE_FIND);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "destroy",
-			   GTK_SIGNAL_FUNC (dialog_destroyed), &dialog);
+	g_signal_connect(G_OBJECT (dialog->dialog), "destroy",
+			 G_CALLBACK (dialog_destroyed), &dialog);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "response",
-			   GTK_SIGNAL_FUNC (dialog_replace_response_handler), dialog);
+	g_signal_connect(G_OBJECT (dialog->dialog), "response",
+			 G_CALLBACK (dialog_replace_response_handler), dialog);
 
 	g_object_unref (G_OBJECT (gui));
 
@@ -308,11 +312,11 @@ dialog_find_get_dialog (void)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog->dialog),
 					 GEDIT_RESPONSE_FIND);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "destroy",
-			   GTK_SIGNAL_FUNC (dialog_destroyed), &dialog);
+	g_signal_connect(G_OBJECT (dialog->dialog), "destroy",
+			 G_CALLBACK (dialog_destroyed), &dialog);
 
-	gtk_signal_connect(GTK_OBJECT (dialog->dialog), "response",
-			   GTK_SIGNAL_FUNC (dialog_find_response_handler), dialog);
+	g_signal_connect(G_OBJECT (dialog->dialog), "response",
+			 G_CALLBACK (dialog_find_response_handler), dialog);
 
 	g_object_unref (G_OBJECT (gui));
 
@@ -453,9 +457,9 @@ find_dlg_find_button_pressed (GeditDialogFind *dialog)
 
 	
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->case_sensitive)))
-		case_sensitive = FALSE;
-	else
 		case_sensitive = TRUE;
+	else
+		case_sensitive = FALSE;
 			
 	if (!gedit_document_find (doc, search_string, from_cursor, case_sensitive))
 	{	
@@ -524,9 +528,9 @@ replace_dlg_find_button_pressed (GeditDialogReplace *dialog)
 
 	
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->case_sensitive)))
-		case_sensitive = FALSE;
-	else
 		case_sensitive = TRUE;
+	else
+		case_sensitive = FALSE;
 			
 	if (!gedit_document_find (doc, search_string, from_cursor, case_sensitive))
 	{	
@@ -606,12 +610,26 @@ replace_dlg_replace_button_pressed (GeditDialogReplace *dialog)
 
 	selected_text = gedit_document_get_selected_text (doc, NULL, NULL);
 
-	if (strcmp (selected_text, search_string) != 0)
+	gedit_debug (DEBUG_SEARCH, "Sel text: %s", selected_text);
+	gedit_debug (DEBUG_SEARCH, "Search string: %s", search_string);
+
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->case_sensitive)))
+		case_sensitive = TRUE;
+	else
+		case_sensitive = FALSE;
+
+	if ((selected_text == NULL) ||
+	    (case_sensitive && (strcmp (selected_text, search_string) != 0)) ||
+	    (!case_sensitive && !g_uft8_caselessnmatch (selected_text, 
+						       search_string, 
+						       strlen (selected_text), 
+						       strlen (search_string)) != 0))
 	{
 		gedit_debug (DEBUG_SEARCH, "selected_text (%s) != search_string (%s)", 
 				selected_text, search_string);
 
-		g_free (selected_text);
+		if (selected_text != NULL)
+			g_free (selected_text);
 
 		gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog->dialog), 
 			GEDIT_RESPONSE_REPLACE, FALSE);
@@ -622,14 +640,13 @@ replace_dlg_replace_button_pressed (GeditDialogReplace *dialog)
 	}
 				
 	g_free (selected_text);
-	
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->case_sensitive)))
-		case_sensitive = TRUE;
-	else
-		case_sensitive = FALSE;
+		
+	gedit_debug (DEBUG_SEARCH, "Replace string: %s", replace_string);
 
 	gedit_document_replace_selected_text (doc, replace_string);
 
+	gedit_debug (DEBUG_SEARCH, "Replaced");
+
 	/* go ahead and find the next one */
 	if (!gedit_document_find (doc, search_string, TRUE, case_sensitive))
 	{	
@@ -646,6 +663,8 @@ replace_dlg_replace_button_pressed (GeditDialogReplace *dialog)
 		
 		gedit_view_scroll_to_cursor (active_view);
 	}
+
+	gedit_debug (DEBUG_SEARCH, "END");
 }
 
 
